package com.jqtx.windows.command;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson.JSON;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.common.factory.AbstractCommand;
import com.jqtx.windows.common.factory.RuntimeContextHolder;
import com.jqtx.windows.common.utils.ValidateUtil;
import com.jqtx.windows.component.CreditResultComponent;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.model.CreditResultModel;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.web.request.SyncCreditResultRequest;
import com.jqtx.windows.web.response.JsonResult;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;


@Service
@Slf4j
public class SyncCreditCommand extends AbstractCommand {
    @Autowired
    private CreditResultComponent creditResultComponent;
    @Autowired
    private LoanComponent loanComponent;

    @Override
    public JsonResult execute() {
        String request = RuntimeContextHolder.currentRuntimeContext().getRequestBody();
        SyncCreditResultRequest syncCreditResultRequest = JSON.parseObject(request, SyncCreditResultRequest.class);
        //
        ValidateUtil.valid(syncCreditResultRequest);
        try {
            CreditResultModel creditResultModel = BeanUtil.toBean(syncCreditResultRequest, CreditResultModel.class);
            creditResultModel.setCreditStatus(syncCreditResultRequest.getStatus());
            creditResultComponent.insert(creditResultModel);
            if (StringUtils.isNotEmpty(creditResultModel.getLoanNo())) {
                boolean pass=syncCreditResultRequest.getStatus().equals("1");
                LoanModel loanModel = new LoanModel();
                loanModel.setLoanNo(creditResultModel.getLoanNo());
                loanModel.setLoanStatus(pass?"AUDITED":"CANCELED");
                loanModel.setGmtModified(LocalDateTime.now());
                loanComponent.updateByLoanNo(loanModel);
            }


        } catch (Exception e) {
            log.error("同步授信结果授信编号:{},报错:{}", syncCreditResultRequest.getOrderNo(), e.getMessage(), e);
            throw new BizException("同步授信结果错误");
        }
        return JsonResult.success();
    }
}
